==> kubernetes-client-4.13.1-sources.jar: io/fabric8/kubernetes/client/dsl/internal/core/v1/SecretOperationsImpl.java <==

                                          
      

package io.fabric8.kubernetes.client.dsl.internal.core.v1;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DoneableSecret;
import io.fabric8.kubernetes.api.model.Secret;
import io.fabric8.kubernetes.api.model.SecretList;
import io.fabric8.kubernetes.api.model.DoneableSecret;

import java.util.Map;
import java.util.TreeMap;


public class SecretOperationsImpl extends HasMetadataOperation<Secret, SecretList, DoneableSecret, Resource<Secret, DoneableSecret>> {

  public SecretOperationsImpl(OkHttpClient client, Config config) {
    this(client, config, null);
  }

  public SecretOperationsImpl(OkHttpClient client, Config config, String namespace) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withNamespace(namespace).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public SecretOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("")
    .withApiGroupVersion("v1")
    .withPlural("secrets"));
    this.type = Secret.class;
    this.listType = SecretList.class;
    this.doneableType = DoneableSecret.class;
  }

  public SecretOperationsImpl newInstance(OperationContext context) {
    return new SecretOperationsImpl(context);
  }

  @Override
  public boolean isResourceNamespaced() {
    return true;
  }
}

==> kubernetes-client-5.0.2-sources.jar: io/fabric8/kubernetes/client/dsl/internal/core/v1/SecretOperationsImpl.java <==

                                          
      

package io.fabric8.kubernetes.client.dsl.internal.core.v1;

import io.fabric8.kubernetes.api.builder.Visitor;
import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.Secret;
import io.fabric8.kubernetes.api.model.SecretBuilder;
import io.fabric8.kubernetes.api.model.SecretList;

import java.util.Map;
import java.util.TreeMap;


public class SecretOperationsImpl extends HasMetadataOperation<Secret, SecretList, Resource<Secret>> {

  public SecretOperationsImpl(OkHttpClient client, Config config) {
    this(client, config, null);
  }

  public SecretOperationsImpl(OkHttpClient client, Config config, String namespace) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withNamespace(namespace).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public SecretOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("")
    .withApiGroupVersion("v1")
    .withPlural("secrets"));
    this.type = Secret.class;
    this.listType = SecretList.class;
  }

  public SecretOperationsImpl newInstance(OperationContext context) {
    return new SecretOperationsImpl(context);
  }

  @Override
  public Secret edit(Visitor... visitors) {
    return patch(new SecretBuilder(getMandatory()).accept(visitors).build());
  }

  @Override
  public boolean isResourceNamespaced() {
    return true;
  }
}
